@@ -27,9 +27,16 @@
 /**
  * The grantlee's filter to get items of a document table
  */
-class SKGDocumentTableFilter : public Grantlee::Filter
+class SKGDocumentTableFilter final : public Grantlee::Filter
 {
 public:
+    Q_DISABLE_COPY(SKGDocumentTableFilter)
+
+    /**
+     * Default constructor
+     */
+    SKGDocumentTableFilter() {};
+
     /**
      * Do the filtering
      * @param input the input
@@ -37,21 +44,28 @@ public:
      * @param autoescape the autoescape mode
      * @return the filtered value
      */
-    virtual QVariant doFilter(const QVariant& input, const QVariant& argument = QVariant(), bool autoescape = false) const override;
+    QVariant doFilter(const QVariant& input, const QVariant& argument = QVariant(), bool autoescape = false) const override;
 
     /**
      * To know if the filter is safe
      * @return true or false
      */
-    virtual bool isSafe() const override;
+    bool isSafe() const override;
 };
 
 /**
  * The grantlee's filter to get display of an attrivute
  */
-class SKGDocumentDisplayFilter : public Grantlee::Filter
+class SKGDocumentDisplayFilter final : public Grantlee::Filter
 {
 public:
+    Q_DISABLE_COPY(SKGDocumentDisplayFilter)
+
+    /**
+     * Default constructor
+     */
+    SKGDocumentDisplayFilter() {};
+
     /**
      * Do the filtering
      * @param input the input
@@ -59,21 +73,28 @@ public:
      * @param autoescape the autoescape mode
      * @return the filtered value
      */
-    virtual QVariant doFilter(const QVariant& input, const QVariant& argument = QVariant(), bool autoescape = false) const override;
+    QVariant doFilter(const QVariant& input, const QVariant& argument = QVariant(), bool autoescape = false) const override;
 
     /**
      * To know if the filter is safe
      * @return true or false
      */
-    virtual bool isSafe() const override;
+    bool isSafe() const override;
 };
 
 /**
  * The grantlee's filter to format percent
  */
-class SKGPercentFilter : public Grantlee::Filter
+class SKGPercentFilter final : public Grantlee::Filter
 {
 public:
+    Q_DISABLE_COPY(SKGPercentFilter)
+
+    /**
+     * Default constructor
+     */
+    SKGPercentFilter() {};
+
     /**
      * Do the filtering
      * @param input the input
@@ -81,21 +102,28 @@ public:
      * @param autoescape the autoescape mode
      * @return the filtered value
      */
-    virtual QVariant doFilter(const QVariant& input, const QVariant& argument = QVariant(), bool autoescape = false) const override;
+    QVariant doFilter(const QVariant& input, const QVariant& argument = QVariant(), bool autoescape = false) const override;
 
     /**
      * To know if the filter is safe
      * @return true or false
      */
-    virtual bool isSafe() const override;
+    bool isSafe() const override;
 };
 
 /**
  * The grantlee's filter to dump objects
  */
-class SKGDumpFilter : public Grantlee::Filter
+class SKGDumpFilter final : public Grantlee::Filter
 {
 public:
+    Q_DISABLE_COPY(SKGDumpFilter)
+
+    /**
+     * Default constructor
+     */
+    SKGDumpFilter() {};
+
     /**
      * Do the filtering
      * @param input the input
@@ -103,21 +131,28 @@ public:
      * @param autoescape the autoescape mode
      * @return the filtered value
      */
-    virtual QVariant doFilter(const QVariant& input, const QVariant& argument = QVariant(), bool autoescape = false) const override;
+    QVariant doFilter(const QVariant& input, const QVariant& argument = QVariant(), bool autoescape = false) const override;
 
     /**
      * To know if the filter is safe
      * @return true or false
      */
-    virtual bool isSafe() const override;
+    bool isSafe() const override;
 };
 
 /**
  * The grantlee's filter to format money
  */
-class SKGMoneyFilter : public Grantlee::Filter
+class SKGMoneyFilter final : public Grantlee::Filter
 {
 public:
+    Q_DISABLE_COPY(SKGMoneyFilter)
+
+    /**
+     * Default constructor
+     */
+    SKGMoneyFilter() {};
+
     /**
      * Do the filtering
      * @param input the input
@@ -125,21 +160,28 @@ public:
      * @param autoescape the autoescape mode
      * @return the filtered value
      */
-    virtual QVariant doFilter(const QVariant& input, const QVariant& argument = QVariant(), bool autoescape = false) const override;
+    QVariant doFilter(const QVariant& input, const QVariant& argument = QVariant(), bool autoescape = false) const override;
 
     /**
      * To know if the filter is safe
      * @return true or false
      */
-    virtual bool isSafe() const override;
+    bool isSafe() const override;
 };
 
 /**
  * The grantlee's filter to encode url
  */
-class SKGUrlEncodeFilter : public Grantlee::Filter
+class SKGUrlEncodeFilter final : public Grantlee::Filter
 {
 public:
+    Q_DISABLE_COPY(SKGUrlEncodeFilter)
+
+    /**
+     * Default constructor
+     */
+    SKGUrlEncodeFilter() {};
+
     /**
      * Do the filtering
      * @param input the input
@@ -147,12 +189,12 @@ public:
      * @param autoescape the autoescape mode
      * @return the filtered value
      */
-    virtual QVariant doFilter(const QVariant& input, const QVariant& argument = QVariant(), bool autoescape = false) const override;
+    QVariant doFilter(const QVariant& input, const QVariant& argument = QVariant(), bool autoescape = false) const override;
 
     /**
      * To know if the filter is safe
      * @return true or false
      */
-    virtual bool isSafe() const override;
+    bool isSafe() const override;
 };
 #endif  // SKGDOCUMENTFILTER_H
