@@ -51,7 +51,8 @@ SKGImportPluginBackend::SKGImportPluginBackend(QObject* iImporter, const QVarian
     Q_UNUSED(iArg);
 
     QString a = QStringLiteral("skrooge/backends");
-    for (const auto& dir : QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, a, QStandardPaths::LocateDirectory)) {
+    const auto dirs = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, a, QStandardPaths::LocateDirectory);
+    for (const auto& dir : dirs) {
         QDirIterator it(dir, QStringList() << QStringLiteral("*.backend"));
         while (it.hasNext()) {
             m_listBackends.push_back(QFileInfo(it.next()).baseName().toUpper());
