@@ -426,7 +426,7 @@ SKGError SKGImportPluginCsv::importFile()
 
                         // Valuate mandatory attribute with default value
                         if (noUnitColumn && i == 0) {
-                            err = m_importer->getDefaultUnit(defUnit, nullptr);
+                            err = m_importer->getDefaultUnit(defUnit);
                         }
                         IFOKDO(err, currentOperation.setUnit(defUnit))
 
