@@ -103,7 +103,7 @@ SKGError SKGImportPluginOfx::importFile()
                     // Get unit
                     SKGUnitObject unit;
                     if (!err2) {
-                        err2 = m_importer->getDefaultUnit(unit, nullptr);
+                        err2 = m_importer->getDefaultUnit(unit);
                     }
 
                     // Current amount
@@ -377,7 +377,7 @@ int SKGImportPluginOfx::ofxTransactionCallback(struct OfxTransactionData data, v
 
         // Get unit
         SKGUnitObject unit;
-        SKGImportPluginOfx::m_ofxError = impotExporter->getDefaultUnit(unit, nullptr);
+        SKGImportPluginOfx::m_ofxError = impotExporter->getDefaultUnit(unit);
 
         // Create id
         QString ID;
