@@ -46,6 +46,11 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
 
     ui.kUseScheduledOperation->hide();
 
+    ui.kTopBtn->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-up-double")));
+    ui.kUpBtn->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-up")));
+    ui.kDownBtn->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-down")));
+    ui.kBottomBtn->setIcon(SKGServices::fromTheme(QStringLiteral("arrow-down-double")));
+
     ui.kPeriodLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("t_period"))));
     ui.kYearLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("i_year"))));
     ui.kMonthLbl->setText(i18n("%1:", iDocument->getDisplay(QStringLiteral("i_month"))));
@@ -104,14 +109,14 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
                                        Qt::META + Qt::Key_2);
     ui.kView->getShowWidget()->addSeparator();
     ui.kView->getShowWidget()->addItem(QStringLiteral("previousYear"), i18nc("Noun, budget items to display", "Previous year"), QStringLiteral("view-calendar-month"),
-                                       QStringLiteral("t_PERIOD LIKE STRFTIME('%Y', date('now','-1 Year'))||'%'"),
+                                       QStringLiteral("t_PERIOD LIKE STRFTIME('%Y', date('now','start of year','-1 day'))||'%'"),
                                        QStringLiteral(""),
                                        QStringLiteral("none"),
                                        QStringLiteral(""),
                                        QStringLiteral("all"),
                                        Qt::META + Qt::Key_5);
     ui.kView->getShowWidget()->addItem(QStringLiteral("previousMonth"), i18nc("Noun, budget items to display", "Previous month"), QStringLiteral("view-calendar-week"),
-                                       QStringLiteral("t_PERIOD=STRFTIME('%Y-%m', date('now','-1 Month'))"),
+                                       QStringLiteral("t_PERIOD=STRFTIME('%Y-%m', date('now','start of month','-1 day'))"),
                                        QStringLiteral(""),
                                        QStringLiteral("none"),
                                        QStringLiteral(""),
@@ -141,6 +146,7 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
         // Bind operation view
         m_objectModel = new SKGObjectModel(doc, QStringLiteral("v_budget_display"), QStringLiteral("1=0"), this, QStringLiteral(""), false);
         ui.kView->setModel(m_objectModel);
+        ui.kSortButton->setVisible(false);
     }
 
     connect(ui.kView->getView(), &SKGTreeView::doubleClicked, SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("open")).data(), &QAction::trigger);
@@ -174,6 +180,23 @@ SKGBudgetPluginWidget::SKGBudgetPluginWidget(SKGDocument* iDocument)
         ui.kWidgetSelector->addButton(SKGServices::fromTheme(QStringLiteral("view-financial-transfer")), i18n("Rules"), i18n("Display the edit panel for rules"), list);
     }
     connect(ui.kWidgetSelector, &SKGWidgetSelector::selectedModeChanged, this, &SKGBudgetPluginWidget::onBtnModeClicked, Qt::QueuedConnection);
+    connect(ui.kAddBtn, &QPushButton::clicked, this, &SKGBudgetPluginWidget::onAddClicked);
+    connect(ui.kModifyBtn, &QPushButton::clicked, this, &SKGBudgetPluginWidget::onUpdateClicked);
+    connect(ui.kAmountEdit, &SKGCalculatorEdit::textChanged, this, &SKGBudgetPluginWidget::onCreatorModified);
+    connect(ui.kPeriod, static_cast<void (SKGComboBox::*)(const QString&)>(&SKGComboBox::currentIndexChanged), this, &SKGBudgetPluginWidget::onCreatorModified);
+    connect(ui.kYearCheck, &QCheckBox::toggled, ui.kYearRule, &QSpinBox::setEnabled);
+    connect(ui.kMonthCheck, &QCheckBox::toggled, ui.kMonthRule, &QSpinBox::setEnabled);
+    connect(ui.kCategoryCheck, &QCheckBox::toggled, ui.kCategoryRule, &SKGComboBox::setEnabled);
+    connect(ui.kCategoryTransferCheck, &QCheckBox::toggled, ui.kCategoryTransfer, &SKGComboBox::setEnabled);
+    connect(ui.kModeCmb, static_cast<void (SKGComboBox::*)(int)>(&SKGComboBox::currentIndexChanged), this, &SKGBudgetPluginWidget::onCreatorModified);
+    connect(ui.kAutoBudgetCheck, &QCheckBox::toggled, ui.kYearAutoBase, &QSpinBox::setEnabled);
+    connect(ui.kAutoBudgetCheck, &QCheckBox::toggled, ui.kRemovePrevious, &QCheckBox::setEnabled);
+    connect(ui.kAutoBudgetCheck, &QCheckBox::toggled, ui.kUseScheduledOperation, &QCheckBox::setEnabled);
+
+    connect(ui.kTopBtn, &QToolButton::clicked, this, &SKGBudgetPluginWidget::onTop);
+    connect(ui.kUpBtn, &QToolButton::clicked, this, &SKGBudgetPluginWidget::onUp);
+    connect(ui.kDownBtn, &QToolButton::clicked, this, &SKGBudgetPluginWidget::onDown);
+    connect(ui.kBottomBtn, &QToolButton::clicked, this, &SKGBudgetPluginWidget::onBottom);
 
     ui.kWidgetSelector->setSelectedMode(0);
 
@@ -301,11 +324,13 @@ void SKGBudgetPluginWidget::onBtnModeClicked(int mode)
         m_viewBudget = ui.kView->getState();
         m_objectModel->setFilter(QStringLiteral(""));
         m_objectModel->setTable(QStringLiteral("v_budgetrule_display"));
+        ui.kSortButton->setVisible(true);
         ui.kView->setState(m_viewRule);
     } else if (mode != 2 && m_objectModel->getTable() != QStringLiteral("v_budget_display")) {
         ui.kView->getShowWidget()->setEnabled(true);
         m_viewRule = ui.kView->getState();
         m_objectModel->setTable(QStringLiteral("v_budget_display"));
+        ui.kSortButton->setVisible(false);
         ui.kView->setState(m_viewBudget);
     }
 
@@ -324,6 +349,8 @@ void SKGBudgetPluginWidget::onAddClicked()
             SKGBEGINTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget rule creation")  , err);
             SKGBudgetRuleObject budgetRule(getDocument());
             IFOKDO(err, updateBudgetRule(budgetRule))
+            IFOKDO(err, budgetRule.setOrder(-1));
+            IFOKDO(err, budgetRule.save());
             uniqueIDs.push_back(budgetRule.getUniqueID());
 
             // Send message
@@ -630,5 +657,173 @@ void SKGBudgetPluginWidget::refreshInfoZone()
     }
 }
 
+void SKGBudgetPluginWidget::onTop()
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(1, err);
+
+    // Get rules
+    SKGObjectBase::SKGListSKGObjectBase  rules = getSelectedObjects();
+    int nb = rules.count();
+    {
+        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget rule update"), err, nb);
+        for (int i = nb - 1; !err && i >= 0; --i) {
+            SKGBudgetRuleObject rule(rules.at(i));
+
+            double order = 1;
+            SKGStringListList result;
+            err = getDocument()->executeSelectSqliteOrder(QStringLiteral("SELECT min(f_sortorder) from budgetrule"), result);
+            if (!err && result.count() == 2) {
+                order = SKGServices::stringToDouble(result.at(1).at(0)) - 1;
+            }
+
+            IFOKDO(err, rule.setOrder(order))
+            IFOKDO(err, rule.save())
+
+            // Send message
+            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The budget rule '%1' has been updated", rule.getDisplayName()), SKGDocument::Hidden));
+
+            IFOKDO(err, getDocument()->stepForward(i + 1))
+        }
+    }
+
+    // status bar
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Budget rule updated")))
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Budget rule update failed"));
+    }
+
+    // Display error
+    SKGMainPanel::displayErrorMessage(err);
+}
+
+void SKGBudgetPluginWidget::onUp()
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(1, err);
+
+    // Get rules
+    SKGObjectBase::SKGListSKGObjectBase  rules = getSelectedObjects();
+    int nb = rules.count();
+    {
+        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget rule update"), err, nb);
+        for (int i = 0; !err && i < nb; ++i) {
+            SKGBudgetRuleObject rule(rules.at(i));
+
+            double order = rule.getOrder();
+            SKGStringListList result;
+            err = getDocument()->executeSelectSqliteOrder("SELECT f_sortorder from budgetrule where f_sortorder<" % SKGServices::doubleToString(order) % " ORDER BY f_sortorder DESC", result);
+            IFOK(err) {
+                if (result.count() == 2) {
+                    order = SKGServices::stringToDouble(result.at(1).at(0)) - 1;
+                } else if (result.count() >= 2) {
+                    order = (SKGServices::stringToDouble(result.at(1).at(0)) + SKGServices::stringToDouble(result.at(2).at(0))) / 2;
+                }
+            }
+
+            IFOKDO(err, rule.setOrder(order))
+            IFOKDO(err, rule.save())
+
+            // Send message
+            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The budget rule '%1' has been updated", rule.getDisplayName()), SKGDocument::Hidden));
+
+            IFOKDO(err, getDocument()->stepForward(i + 1))
+        }
+    }
+
+    // status bar
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Budget rule updated")))
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Budget rule update failed"));
+    }
+
+    // Display error
+    SKGMainPanel::displayErrorMessage(err);
+}
+
+void SKGBudgetPluginWidget::onDown()
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(1, err);
+
+    // Get rules
+    SKGObjectBase::SKGListSKGObjectBase  rules = getSelectedObjects();
+    int nb = rules.count();
+    {
+        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget rule update"), err, nb);
+        for (int i = nb - 1; !err && i >= 0; --i) {
+            SKGBudgetRuleObject rule(rules.at(i));
+
+            double order = rule.getOrder();
+            SKGStringListList result;
+            err = getDocument()->executeSelectSqliteOrder("SELECT f_sortorder from budgetrule where f_sortorder>" % SKGServices::doubleToString(order) % " ORDER BY f_sortorder ASC", result);
+            IFOK(err) {
+                if (result.count() == 2) {
+                    order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
+                } else if (result.count() >= 2) {
+                    order = (SKGServices::stringToDouble(result.at(1).at(0)) + SKGServices::stringToDouble(result.at(2).at(0))) / 2;
+                }
+            }
+
+            IFOKDO(err, rule.setOrder(order))
+            IFOKDO(err, rule.save())
+
+            // Send message
+            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The budget rule '%1' has been updated", rule.getDisplayName()), SKGDocument::Hidden));
+
+            IFOKDO(err, getDocument()->stepForward(i + 1))
+        }
+    }
+
+    // status bar
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Budget rule updated")))
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Budget rule update failed"));
+    }
+
+    // Display error
+    SKGMainPanel::displayErrorMessage(err);
+}
+
+void SKGBudgetPluginWidget::onBottom()
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(1, err);
+
+    // Get rules
+    SKGObjectBase::SKGListSKGObjectBase  rules = getSelectedObjects();
+    int nb = rules.count();
+    {
+        SKGBEGINPROGRESSTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Budget rule update"), err, nb);
+        for (int i = 0; !err && i < nb; ++i) {
+            SKGBudgetRuleObject rule(rules.at(i));
+
+            double order = 1;
+            SKGStringListList result;
+            err = getDocument()->executeSelectSqliteOrder(QStringLiteral("SELECT max(f_sortorder) from budgetrule"), result);
+            if (!err && result.count() == 2) {
+                order = SKGServices::stringToDouble(result.at(1).at(0)) + 1;
+            }
+
+            IFOKDO(err, rule.setOrder(order))
+            IFOKDO(err, rule.save())
+
+            // Send message
+            IFOKDO(err, getDocument()->sendMessage(i18nc("An information to the user", "The budget rule '%1' has been updated", rule.getDisplayName()), SKGDocument::Hidden));
+
+            IFOKDO(err, getDocument()->stepForward(i + 1))
+        }
+    }
+
+    // status bar
+    IFOKDO(err, SKGError(0, i18nc("Successful message after an user action", "Budget rule updated")))
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message",  "Budget rule update failed"));
+    }
+
+    // Display error
+    SKGMainPanel::displayErrorMessage(err);
+}
+
 
 
