@@ -48,21 +48,21 @@ public:
      * @return a string containing all information needed to set the same state.
      * Could be an XML stream
      */
-    virtual QString getState() Q_DECL_OVERRIDE;
+    virtual QString getState() override;
 
     /**
      * Set the current state
      * MUST BE OVERWRITTEN
      * @param iState must be interpreted to set the state of the widget
      */
-    virtual void setState(const QString& iState) Q_DECL_OVERRIDE;
+    virtual void setState(const QString& iState) override;
 
     /**
      * Get attribute name to save the default state
      * MUST BE OVERWRITTEN
      * @return attribute name to save the default state.
      */
-    virtual QString getDefaultStateAttribute() Q_DECL_OVERRIDE;
+    virtual QString getDefaultStateAttribute() override;
 
 private Q_SLOTS:
     void dataModified(const QString& iTableName = QString(), int iIdTransaction = 0);
