@@ -149,9 +149,7 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument, const QStringList&
         if (!selection.isEmpty()) {
             SKGObjectBase obj = selection[0];
             QString name = obj.getAttribute(QStringLiteral("t_name"));
-
-            QString url = QString("skg://skrooge_operation_plugin/?title_icon=view-refresh&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Operations modified or created during the action '%1'", name)) %
-                                  "&operationWhereClause=" % SKGServices::encodeForUrl("id in (SELECT i_object_id FROM doctransactionitem WHERE rd_doctransaction_id=" % SKGServices::intToString(obj.getID()) % " AND t_object_table='operation')"));
+            QString url = QString("skg://skrooge_operation_plugin/?title_icon=view-refresh&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Operations modified or created during the action '%1'", name)) % "&operationWhereClause=" % SKGServices::encodeForUrl("id in (SELECT i_object_id FROM doctransactionitem WHERE rd_doctransaction_id=" % SKGServices::intToString(obj.getID()) % " AND t_object_table='operation')"));
             SKGMainPanel::getMainPanel()->SKGMainPanel::openPage(url);
         }
     });
