@@ -260,6 +260,20 @@ public:
      */
     SKGError getTransferCategory(SKGCategoryObject& oCategory) const;
 
+    /**
+     * Set the order for the rule
+     * @param iOrder the order. (-1 means "at the end")
+     * @return an object managing the error
+     *   @see SKGError
+     */
+    SKGError setOrder(double iOrder);
+
+    /**
+     * Get the order for the rule
+     * @return the order
+     */
+    double getOrder() const;
+
     /**
      * Process all rules
      * @param iDocument the document containing the object
