@@ -139,7 +139,8 @@ SKGError SKGImportExportManager::getDefaultAccount(SKGAccountObject& oAccount)
         if (!number.isEmpty()) {
             whereClause += " OR t_number='" % number % "'";
         }
-        for (const auto& val : name.split(' ')) {
+        const auto words = name.split(' ');
+        for (const auto& val : words) {
             whereClause += " OR t_number='" % val % "'";
         }
 
@@ -214,9 +215,6 @@ SKGError SKGImportExportManager::getDefaultUnit(SKGUnitObject& oUnit, const QDat
         err = m_document->getObjects(QStringLiteral("v_unit"), wc % " ORDER BY ABS(f_CURRENTAMOUNT-1) ASC" , listUnits);
         IFOK(err) {
             if (listUnits.isEmpty()) {
-                // Not found, we have to create one
-                QDateTime now = QDateTime::currentDateTime();
-
                 SKGUnitObject unit(m_document);
                 QString name = i18nc("Noun",  "Unit for import");
                 err = unit.setName(name);
@@ -692,6 +690,7 @@ SKGError SKGImportExportManager::anonymize()
             err = SKGError(ERR_ABORT, i18nc("An information message",  "The document must be saved to be anonymized."), QStringLiteral("skg://file_save"));
         } else {
             {
+                // Anonymize data
                 QStringList sqlOrders;
                 sqlOrders << QStringLiteral("UPDATE bank SET t_bank_number='', t_name='bank_'||id")
                           << QStringLiteral("UPDATE account SET t_number='', t_agency_number='', t_agency_address='', t_comment='', t_name='account_'||id")
@@ -711,7 +710,10 @@ SKGError SKGImportExportManager::anonymize()
                 }
             }
 
+            // Remove transactions
             IFOKDO(err, m_document->removeAllTransactions())
+
+            // Save new file
             QString newName = m_document->getCurrentFileName().replace(QStringLiteral(".skg"), QStringLiteral("-anonymized.skg"));
             if (newName == m_document->getCurrentFileName()) {
                 newName = m_document->getCurrentFileName() % "-anonymized.skg";
