@@ -32,7 +32,7 @@ class SKGInterestObject;
 /**
  * This class is interest option for an account
  */
-class SKGBANKMODELER_EXPORT SKGInterestObject : public SKGObjectBase
+class SKGBANKMODELER_EXPORT SKGInterestObject final : public SKGObjectBase
 {
     Q_OBJECT
     /**
@@ -88,12 +88,12 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGInterestObject& operator= (const SKGObjectBase& iObject) override;
+    const SKGInterestObject& operator= (const SKGObjectBase& iObject) override;
 
     /**
      * Destructor
      */
-    virtual ~SKGInterestObject();
+    ~SKGInterestObject();
 
     /**
      * Get the parent account
@@ -101,7 +101,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError getAccount(SKGAccountObject& oAccount) const;
+    SKGError getAccount(SKGAccountObject& oAccount) const;
 
     /**
      * Set the parent account
@@ -109,7 +109,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setAccount(const SKGAccountObject& iAccount);
+    SKGError setAccount(const SKGAccountObject& iAccount);
 
     /**
      * Set the quantity for the date of this unit
@@ -117,13 +117,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setRate(double iValue);
+    SKGError setRate(double iValue);
 
     /**
      * Get the quantity for the date of this unit
      * @return the quantity
      */
-    virtual double getRate() const;
+    double getRate() const;
 
     /**
      * Set date of this value
@@ -132,13 +132,13 @@ public:
      *   @see SKGError
      */
     // cppcheck-suppress passedByValue
-    virtual SKGError setDate(const QDate iDate);
+    SKGError setDate(const QDate iDate);
 
     /**
      * Get date of this value
      * @return the date
      */
-    virtual QDate getDate() const;
+    QDate getDate() const;
 
     /**
      * Set income value date mode
@@ -146,13 +146,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setIncomeValueDateMode(SKGInterestObject::ValueDateMode iMode);
+    SKGError setIncomeValueDateMode(SKGInterestObject::ValueDateMode iMode);
 
     /**
      * Get income value date mode
      * @return the income value date mode
      */
-    virtual SKGInterestObject::ValueDateMode getIncomeValueDateMode() const;
+    SKGInterestObject::ValueDateMode getIncomeValueDateMode() const;
 
     /**
      * Set expenditue value date mode
@@ -160,13 +160,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setExpenditueValueDateMode(SKGInterestObject::ValueDateMode iMode);
+    SKGError setExpenditueValueDateMode(SKGInterestObject::ValueDateMode iMode);
 
     /**
      * Get expenditue value date mode
      * @return the expenditue value date mode
      */
-    virtual SKGInterestObject::ValueDateMode getExpenditueValueDateMode() const;
+    SKGInterestObject::ValueDateMode getExpenditueValueDateMode() const;
 
     /**
      * Set interest computation mode
@@ -174,13 +174,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setInterestComputationMode(SKGInterestObject::InterestMode iMode);
+    SKGError setInterestComputationMode(SKGInterestObject::InterestMode iMode);
 
     /**
      * Get interest computation mode
      * @return the interest computation mode
      */
-    virtual SKGInterestObject::InterestMode getInterestComputationMode() const;
+    SKGInterestObject::InterestMode getInterestComputationMode() const;
 
 protected:
     /**
@@ -188,7 +188,7 @@ protected:
      * For this class, the whereclause is based on date + unit
      * @return the where clause
      */
-    virtual QString getWhereclauseId() const override;
+    QString getWhereclauseId() const override;
 };
 /**
  * Declare the class
