@@ -425,7 +425,7 @@ QStringList SKGReportBank::get5MainCategoriesVariation()
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10);
         SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
-        table = doc ? doc->get5MainCategoriesVariationList(getPeriod(), getPreviousPeriod(), false, nullptr) : QStringList();
+        table = doc ? doc->get5MainCategoriesVariationList(getPeriod(), getPreviousPeriod(), false) : QStringList();
         m_cache[cacheId] = table;
     }
     return table;
@@ -438,7 +438,7 @@ QStringList SKGReportBank::get5MainCategoriesVariationIssue()
     if (table.isEmpty()) {
         SKGTRACEINFUNC(10);
         SKGDocumentBank* doc = static_cast<SKGDocumentBank*>(m_document);
-        table = doc ? doc->get5MainCategoriesVariationList(getPeriod(), getPreviousPeriod(), true, nullptr) : QStringList();
+        table = doc ? doc->get5MainCategoriesVariationList(getPeriod(), getPreviousPeriod(), true) : QStringList();
         m_cache[cacheId] = table;
     }
     return table;
