@@ -30,7 +30,7 @@
 /**
  * This class allows to define rules
  */
-class SKGBANKMODELER_EXPORT SKGRuleObject : public SKGObjectBase
+class SKGBANKMODELER_EXPORT SKGRuleObject final : public SKGObjectBase
 {
     Q_OBJECT
     /**
@@ -101,18 +101,18 @@ public:
      * Operator affectation
      * @param iObject the object to copy
      */
-    virtual const SKGRuleObject& operator= (const SKGObjectBase& iObject) override;
+    const SKGRuleObject& operator= (const SKGObjectBase& iObject) override;
 
     /**
      * Destructor
      */
-    virtual ~SKGRuleObject();
+    ~SKGRuleObject();
 
     /**
      * Return the name of the object for the display
      * @return name of the object
      */
-    virtual QString getDisplayName() const override;
+    QString getDisplayName() const override;
 
     /**
      * Set the XML for the search definition
@@ -128,13 +128,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setXMLSearchDefinition(const QString& iXml);
+    SKGError setXMLSearchDefinition(const QString& iXml);
 
     /**
      * Get the XML for the search definition
      * @return the XML
      */
-    virtual QString getXMLSearchDefinition() const;
+    QString getXMLSearchDefinition() const;
 
     /**
      * Set the XML for the action definition
@@ -166,13 +166,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setXMLActionDefinition(const QString& iXml);
+    SKGError setXMLActionDefinition(const QString& iXml);
 
     /**
      * Get the XML for the action definition
      * @return the XML
      */
-    virtual QString getXMLActionDefinition() const;
+    QString getXMLActionDefinition() const;
 
     /**
      * Set the search description
@@ -180,13 +180,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setSearchDescription(const QString& iDescription);
+    SKGError setSearchDescription(const QString& iDescription);
 
     /**
      * Get the search description
      * @return the description
      */
-    virtual QString getSearchDescription() const;
+    QString getSearchDescription() const;
 
     /**
      * Set the action description
@@ -194,13 +194,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setActionDescription(const QString& iDescription);
+    SKGError setActionDescription(const QString& iDescription);
 
     /**
      * Get the action description
      * @return the description
      */
-    virtual QString getActionDescription() const;
+    QString getActionDescription() const;
 
 
     /**
@@ -209,13 +209,13 @@ public:
     * @return an object managing the error
     *   @see SKGError
     */
-    virtual SKGError setActionType(SKGRuleObject::ActionType iType);
+    SKGError setActionType(SKGRuleObject::ActionType iType);
 
     /**
      * Get the action type
      * @return the type
      */
-    virtual SKGRuleObject::ActionType getActionType() const;
+    SKGRuleObject::ActionType getActionType() const;
 
     /**
      * Set the order for the rule
@@ -223,13 +223,13 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError setOrder(double iOrder);
+    SKGError setOrder(double iOrder);
 
     /**
      * Get the order for the rule
      * @return the order
      */
-    virtual double getOrder() const;
+    double getOrder() const;
 
     /**
      * To bookmark or not an account
@@ -237,14 +237,14 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError bookmark(bool iBookmark);
+    SKGError bookmark(bool iBookmark);
 
     /**
      * To know if the account is bookmarked
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual bool isBookmarked() const;
+    bool isBookmarked() const;
 
     /**
      * save the object into the database
@@ -255,7 +255,7 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError save(bool iInsertOrUpdate = true, bool iReloadAfterSave = true) override;
+    SKGError save(bool iInsertOrUpdate = true, bool iReloadAfterSave = true) override;
 
     /**
      * Execute actions
@@ -263,20 +263,20 @@ public:
      * @return an object managing the error
      *   @see SKGError
      */
-    virtual SKGError execute(ProcessMode iMode = SKGRuleObject::ALL);
+    SKGError execute(ProcessMode iMode = SKGRuleObject::ALL);
 
     /**
      * Get where clause corresponding to to search condition
      * @param iAdditionalCondition additional select condition
      * @return the where clause
      */
-    virtual QString getSelectSqlOrder(const QString& iAdditionalCondition = QString()) const;
+    QString getSelectSqlOrder(const QString& iAdditionalCondition = QString()) const;
 
     /**
      * Get alarm info
      * @return alarm info
      */
-    virtual SKGRuleObject::SKGAlarmInfo getAlarmInfo() const;
+    SKGRuleObject::SKGAlarmInfo getAlarmInfo() const;
 
     /**
      * Create a rule to update a category on operations having a specific payee
