@@ -409,6 +409,9 @@ protected:
      * @return the where clause
      */
     QString getWhereclauseId() const override;
+
+private:
+    static QList<SKGServices::SKGUnitInfo> currencies;
 };
 /**
  * Declare the class
