@@ -26,15 +26,14 @@
 #include "skgunitobject.h"
 #include "skgdocument.h"
 
-SKGUnitValueObject::SKGUnitValueObject(SKGDocument* iDocument, int iID)
-    : SKGObjectBase(iDocument, QStringLiteral("v_unitvalue"), iID)
-{
-}
+SKGUnitValueObject::SKGUnitValueObject() : SKGUnitValueObject(nullptr)
+{}
 
-SKGUnitValueObject::SKGUnitValueObject(const SKGUnitValueObject& iObject)
-    : SKGObjectBase(iObject)
-{
-}
+SKGUnitValueObject::SKGUnitValueObject(SKGDocument* iDocument, int iID) : SKGObjectBase(iDocument, QStringLiteral("v_unitvalue"), iID)
+{}
+
+SKGUnitValueObject::SKGUnitValueObject(const SKGUnitValueObject& iObject) : SKGObjectBase(iObject)
+{}
 
 SKGUnitValueObject::SKGUnitValueObject(const SKGObjectBase& iObject)
 {
