@@ -22,8 +22,8 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 
-#include <QWidget>
-#include <QList>
+#include <qwidget.h>
+#include <qlist.h>
 
 
 
@@ -160,7 +160,7 @@ public:
     /**
      * Get the tab page of a widget
      * @param iWidget the widget
-     * @return the iParent tab page or NULL
+     * @return the iParent tab page or nullptr
      */
     static SKGTabPage* parentTabPage(QWidget* iWidget);
 
