@@ -129,6 +129,9 @@ int main(int argc, char** argv)
 
     // Manage unicity
     KDBusService service(SKGServices::getEnvVariable(QStringLiteral("SKGNOTUNIQUE")).isEmpty() ? KDBusService::Unique : KDBusService::Multiple);
+    QObject::connect(&service, &KDBusService::activateRequested, [ = ](const QStringList & arguments, const QString & workingDirectory) {
+        SKGMainPanel::getMainPanel()->processArguments(arguments);
+    });
 
     // Creating a main panel on a bank document
     SKGDocumentBank doc;
