@@ -21,7 +21,7 @@
  */
 #include "skgxxxpluginwidget.h"
 
-#include <QDomDocument>
+#include <qdom.h>
 
 #include "skgmainpanel.h"
 #include "skgtraces.h"
@@ -86,8 +86,8 @@ void SKGXXXPluginWidget::refresh()
     SKGTRACEINFUNC(1);
 
     QSqlDatabase* db = getDocument()->getDatabase();
-    setEnabled(db != NULL);
-    if (db != NULL) {
+    setEnabled(db != nullptr);
+    if (db != nullptr) {
         // Refresh yours widgets here
     }
 }
