@@ -20,7 +20,9 @@
  * @author Stephane MANKOWSKI / Guillaume DE BURE
  */
 #include "skgtestmacro.h"
-
+#if QT_VERSION < 0x050700
+#include <klocale.h>
+#endif
 
 /**
  * The main function of the unit test
@@ -32,6 +34,11 @@ int main(int argc, char** argv)
     Q_UNUSED(argc);
     Q_UNUSED(argv);
 
+#if QT_VERSION < 0x050700
+    KLocale::global()->setNegativePrefixCurrencySymbol(false);
+    KLocale::global()->setPositivePrefixCurrencySymbol(false);
+#endif
+
     // Init test
     SKGINITTEST(true);
 
@@ -108,9 +115,9 @@ int main(int argc, char** argv)
     SKGTESTERROR(QStringLiteral("PARAM:executeSqliteOrder"), document1.executeSqliteOrder(QStringLiteral("SELECT WORD('Abc Def', :2)"), map, nullptr), true);
 
     SKGTESTERROR(QStringLiteral("PARAM:executeSqliteOrder"), document1.executeSingleSelectSqliteOrder(QStringLiteral("SELECT TOCURRENCY(1234, 'F')"), result), true);
-    SKGTEST(QStringLiteral("PARAM:executeSqliteOrder-1234 F"), result, QStringLiteral("F 1,234.00"));
+    SKGTEST(QStringLiteral("PARAM:executeSqliteOrder-1234 F"), result.remove(' '), QStringLiteral("1,234.00F"));
     SKGTESTERROR(QStringLiteral("PARAM:executeSqliteOrder"), document1.executeSingleSelectSqliteOrder(QStringLiteral("SELECT TOCURRENCY(-1234, (SELECT 'F'))"), result), true);
-    SKGTEST(QStringLiteral("PARAM:executeSqliteOrder-1234 F"), result, QStringLiteral("F -1,234.00"));
+    SKGTEST(QStringLiteral("PARAM:executeSqliteOrder-1234 F"), result.remove(' '), QStringLiteral("-1,234.00F"));
     SKGTESTERROR(QStringLiteral("PARAM:executeSqliteOrder"), document1.executeSingleSelectSqliteOrder(QStringLiteral("SELECT PERIOD((SELECT '2013-03-05'), (SELECT 'D'))"), result), true);
     SKGTEST(QStringLiteral("PARAM:executeSqliteOrder-PERIOD D"), result, QStringLiteral("2013-03-05"));
     SKGTESTERROR(QStringLiteral("PARAM:executeSqliteOrder"), document1.executeSingleSelectSqliteOrder(QStringLiteral("SELECT PERIOD('2013-03-05', 'W')"), result), true);
